==> bigloo1.3b.tar.gz: bigloo1.3/comptime1.3/Cnst/walk.scm <==
;*---------------------------------------------------------------------*/
;*    Copyright (c) 1993 by Manuel Serrano. All rights reserved.       */
;*                                                                     */
;*                                     ,--^,                           */
;*                               _ ___/ /|/                            */
;*                           ,;'( )__, ) '                             */
;*                          ;;  //   L__.                              */
;*                          '   \    /  '                              */
;*                               ^   ^                                 */
;*                                                                     */
;*                                                                     */
;*    This program is distributed in the hope that it will be useful.  */
;*    Use and copying of this software and preparation of derivative   */
;*    works based upon this software are permitted, so long as the     */
;*    following conditions are met:                                    */
;*           o credit to the authors is acknowledged following         */
;*             current academic behaviour                              */
;*           o no fees or compensation are charged for use, copies,    */
;*             or access to this software                              */
;*           o this copyright notice is included intact.               */
;*      This software is made available AS IS, and no warranty is made */
;*      about the software or its performance.                         */
;*                                                                     */
;*      Bug descriptions, use reports, comments or suggestions are     */
;*      welcome Send them to                                           */
;*        <Manuel.Serrano@inria.fr>                                    */
;*        Manuel Serrano                                               */
;*        INRIA -- Rocquencourt                                        */
;*        Domaine de Voluceau, BP 105                                  */
;*        78153 Le Chesnay Cedex                                       */
;*        France                                                       */
;*---------------------------------------------------------------------*/


;*---------------------------------------------------------------------*/
;*    serrano/prgm/project/bigloo/comptime1.2/Cnst/walk.scm ...        */
;*                                                                     */
;*    Author      :  Manuel Serrano                                    */
;*    Creation    :  Thu Mar 25 16:26:07 1993                          */
;*    Last change :  Tue Apr 13 10:40:58 1993  (serrano)               */
;*                                                                     */
;*    L'allocation des constantes.                                     */
;*---------------------------------------------------------------------*/

;*---------------------------------------------------------------------*/
;*    Le module                                                        */
;*---------------------------------------------------------------------*/
(module cnst_walk
   (include "Var/variable.sch")
   (import  tools_speek
	    tools_error
	    tools_shape
	    cnst_expression
	    cnst_alloc
	    cnst_init
	    cnst_module
	    var_env
	    engine_param)
   (export  (cnst-walk tree)))

;*---------------------------------------------------------------------*/
;*    cnst-walk ...                                                    */
;*---------------------------------------------------------------------*/
(define (cnst-walk tree) 
   (verbose "   . Cnst" #\Newline)
   (start-partial-error "Cnst")
   (init-cnst-alloc)
   (init-cnst-module)
   (let ((module-init (find-in-global-environment (initialisation-name)
						  *Genv*)))
      (let loop ((walk      tree)
		 (init-form #f))
	 (if (null? walk)
	     (begin
		(fail-if-partial-error)
		(cnst-init-module! init-form)
		tree)
	     (let ((var (car walk)))
		(let (body value)
		   (enter-function (shape var))
		   (cond
		      ((global? var)
		       (global-info-set! var 'used)
		       (set! value (global-value var))
		       (set! body (function-body value))
		       (function-body-set! value (cnst body)))
		      ((local? var)
		       (set! value (local-value var))
		       (if (eq? (local-class var) 'function)
			   (begin
			      (set! body (function-body value))
			      (function-body-set! value (cnst body)))
			   (begin
			      (set! body (return-body value))
			      (return-body-set! value (cnst body))))))
		   (leave-function)
		   (if (eq? var module-init)
		       (loop (cdr walk)
			     (car walk))
		       (loop (cdr walk)
			     init-form))))))))

==> bigloo_1.8b.orig.tar.gz: bigloo-1.8b.orig/comptime1.8/Cnst/walk.scm <==
;*---------------------------------------------------------------------*/
;*    Copyright (c) 1996 by Manuel Serrano. All rights reserved.       */
;*                                                                     */
;*                                     ,--^,                           */
;*                               _ ___/ /|/                            */
;*                           ,;'( )__, ) '                             */
;*                          ;;  //   L__.                              */
;*                          '   \    /  '                              */
;*                               ^   ^                                 */
;*                                                                     */
;*                                                                     */
;*    This program is distributed in the hope that it will be useful.  */
;*    Use and copying of this software and preparation of derivative   */
;*    works based upon this software are permitted, so long as the     */
;*    following conditions are met:                                    */
;*           o credit to the authors is acknowledged following         */
;*             current academic behaviour                              */
;*           o no fees or compensation are charged for use, copies,    */
;*             or access to this software                              */
;*           o this copyright notice is included intact.               */
;*      This software is made available AS IS, and no warranty is made */
;*      about the software or its performance.                         */
;*                                                                     */
;*      Bug descriptions, use reports, comments or suggestions are     */
;*      welcome Send them to                                           */
;*        <Manuel.Serrano@inria.fr>                                    */
;*        Manuel Serrano                                               */
;*        INRIA -- Rocquencourt                                        */
;*        Domaine de Voluceau, BP 105                                  */
;*        78153 Le Chesnay Cedex                                       */
;*        France                                                       */
;*---------------------------------------------------------------------*/


;*=====================================================================*/
;*    serrano/prgm/project/bigloo/comptime1.8/Cnst/walk.scm            */
;*    -------------------------------------------------------------    */
;*    Author      :  Manuel Serrano                                    */
;*    Creation    :  Fri Feb  3 09:46:40 1995                          */
;*    Last change :  Fri Jul 21 10:13:36 1995 (serrano)                */
;*    -------------------------------------------------------------    */
;*    The `constant compilation'                                       */
;*=====================================================================*/

;*---------------------------------------------------------------------*/
;*    The module                                                       */
;*---------------------------------------------------------------------*/
(module cnst_walk
   (include "Tools/pass.sch"
	    "Tools/trace.sch"
	    "Ast/ast.sch")
   (import  tools_shape
	    engine_param
	    ast_env
	    ast_dump
	    ast_global
	    cnst_alloc
	    cnst_cache
	    cnst_ast
	    cnst_initialize)
   (export  (cnst-walk! <global>*)))

;*---------------------------------------------------------------------*/
;*    cnst-walk! ...                                                   */
;*---------------------------------------------------------------------*/
(define (cnst-walk! globals)
   (pass-prelude "Cnst"
		 start-cnst-cache!
		 start-cnst-alloc!
		 initialize-init!)
   (verbose 2 "        [" *init-mode* #\] #\Newline)
   (for-each (lambda (global)
		(enter-function (global-shape global))
		(let* ((fun      (global-value global))
		       (new-body (cnst (function-body fun))))
		   (function-body-set! fun new-body))
		(leave-function))
	     globals)
   (pass-postlude globals
		  initialize-stop!
		  stop-cnst-alloc!
		  stop-cnst-cache!))
